import { ANALYZE_FOR_ENTRY_COMPONENTS, Component, Inject, Injectable, InjectionToken, NgModule } from '@angular/core';
import '@angular/platform-browser';
import { Router, RouterModule } from '@angular/router';
import { animate, state, style, transition, trigger } from '@angular/animations';
import { CommonModule } from '@angular/common';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var baseAnimation = trigger('baseAnimation', [
    state('void', style({ position: 'fixed', opacity: 0 })),
    // route 'enter' transition
    transition(':enter', [
        // css styles at start of transition
        style({ opacity: 0, "z-index": "1001" }),
        // animation and styles at end of transition
        animate('20s', style({ opacity: 1, "z-index": "1001" }))
    ]),
    transition(':leave', [
        // css styles at start of transition
        style({ opacity: 1 }),
        // animation and styles at end of transition
        animate('20s', style({ opacity: 0 }))
    ]),
]);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var ModalOutletComponent = /** @class */ (function () {
    function ModalOutletComponent() {
    }
    ModalOutletComponent.decorators = [
        { type: Component, args: [{
                    selector: 'modal-outlet',
                    template: "\n    <router-outlet name=\"modal\"></router-outlet>\n  ",
                    animations: []
                },] },
    ];
    /** @nocollapse */
    ModalOutletComponent.ctorParameters = function () { return []; };
    return ModalOutletComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var ModalService = /** @class */ (function () {
    function ModalService(router$$1) {
        this.router = router$$1;
    }
    /**
     * @param {?} name
     * @return {?}
     */
    ModalService.prototype.open = /**
     * @param {?} name
     * @return {?}
     */
    function (name) {
        this.router.navigate([{ outlets: { modal: [name] } }], { skipLocationChange: true });
    };
    /**
     * @return {?}
     */
    ModalService.prototype.close = /**
     * @return {?}
     */
    function () {
        this.router.navigate([{ outlets: { modal: null } }], { skipLocationChange: true });
    };
    ModalService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    ModalService.ctorParameters = function () { return [
        { type: Router, decorators: [{ type: Inject, args: [Router,] },] },
    ]; };
    return ModalService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var ModalDialogComponent = /** @class */ (function () {
    function ModalDialogComponent(modalService) {
        this.modalService = modalService;
    }
    /**
     * @return {?}
     */
    ModalDialogComponent.prototype.close = /**
     * @return {?}
     */
    function () {
        this.modalService.close();
    };
    ModalDialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 'modal-dialog',
                    template: "\n    <div  @baseAnimation>\n    <div  class=\"modal fade in show\" tabindex=\"-1\" role=\"dialog\">\n        <div class=\"modal-dialog modal-lg\" role=\"document\">\n          <div class=\"modal-content\">\n            <div class=\"modal-header\">\n              <button type=\"button\" (click)=\"close()\" class=\"close\" data-dismiss=\"modal\" aria-label=\"Close\"><span aria-hidden=\"true\">&times;</span></button>\n              <h4 class=\"modal-title\">\n                <ng-content select=\"[modal-title]\"></ng-content>\n              </h4>\n            </div>\n            <div class=\"modal-body\">\n                <ng-content select=\"[modal-body]\"></ng-content>\n            </div>\n            <div class=\"modal-footer\">\n                <div #footer>\n                    <ng-content select=\"[modal-footer]\"></ng-content>\n                </div>\n                <div *ngIf=\"footer.children.length == 0\">\n                    <button (click)=\"close()\" type=\"button\" class=\"btn btn-default\" data-dismiss=\"modal\">Close</button>\n                    <button type=\"button\" class=\"btn btn-primary\">Submit</button>\n                </div>\n            </div>\n          </div>\n        </div>\n      </div>\n      <div class=\"modal-backdrop fade in\"></div>\n\n    </div>\n  ",
                    animations: [
                        baseAnimation
                    ]
                },] },
    ];
    /** @nocollapse */
    ModalDialogComponent.ctorParameters = function () { return [
        { type: ModalService, },
    ]; };
    return ModalDialogComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//import { ANALYZE_FOR_ENTRY_COMPONENTS } from "@angular/core";
var Modals = new InjectionToken('modals');
/**
 * @param {?} router
 * @param {?} modals
 * @return {?}
 */
function InitModalService(router$$1, modals) {
    var /** @type {?} */ routes = modals.map(function (t) { return { path: t.name, component: t.component, outlet: 'modal' }; });
    var /** @type {?} */ r = router$$1.config.concat(routes);
    router$$1.resetConfig(r);
    return new ModalService(router$$1);
}
var ModalCommonModule = /** @class */ (function () {
    function ModalCommonModule() {
    }
    ModalCommonModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        BrowserAnimationsModule,
                        RouterModule.forChild([])
                    ],
                    declarations: [
                        ModalDialogComponent,
                        ModalOutletComponent
                    ],
                    exports: [
                        ModalDialogComponent,
                        ModalOutletComponent
                    ],
                    providers: []
                },] },
    ];
    /** @nocollapse */
    ModalCommonModule.ctorParameters = function () { return []; };
    return ModalCommonModule;
}());
var RouterModalModule = /** @class */ (function () {
    function RouterModalModule() {
    }
    /**
     * @param {?} modals
     * @return {?}
     */
    RouterModalModule.forRoot = /**
     * @param {?} modals
     * @return {?}
     */
    function (modals) {
        var /** @type {?} */ routes = modals.map(function (t) { return { path: t.name, component: t.component, outlet: 'modal' }; });
        return {
            ngModule: RouterModalModule,
            providers: [
                { provide: Modals, useValue: modals },
                { provide: ANALYZE_FOR_ENTRY_COMPONENTS, multi: true, useValue: modals },
                { provide: ModalService, useFactory: InitModalService, deps: [Router, Modals] }
            ]
        };
    };
    RouterModalModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        ModalCommonModule
                    ],
                    exports: [
                        ModalCommonModule
                    ]
                },] },
    ];
    /** @nocollapse */
    RouterModalModule.ctorParameters = function () { return []; };
    return RouterModalModule;
}());
var ModalModule = /** @class */ (function () {
    function ModalModule() {
    }
    /**
     * @param {?} modals
     * @return {?}
     */
    ModalModule.forRoot = /**
     * @param {?} modals
     * @return {?}
     */
    function (modals) {
        return {
            ngModule: ModalModule,
            providers: [
                { provide: Modals, useValue: modals },
                { provide: ANALYZE_FOR_ENTRY_COMPONENTS, multi: true, useValue: modals },
                { provide: ModalService, useFactory: InitModalService, deps: [Router, Modals] }
            ]
        };
    };
    ModalModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        ModalCommonModule,
                        RouterModule.forRoot([])
                    ],
                    exports: [
                        ModalCommonModule
                    ],
                    providers: []
                },] },
    ];
    /** @nocollapse */
    ModalModule.ctorParameters = function () { return []; };
    return ModalModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * @module
 * @description
 * Entry point for all public APIs of the core package.
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { Modals, InitModalService, ModalCommonModule, RouterModalModule, ModalModule, ModalService, ModalDialogComponent as ɵa, ModalOutletComponent as ɵc, baseAnimation as ɵb };
//# sourceMappingURL=index.es5.js.map
