import { ANALYZE_FOR_ENTRY_COMPONENTS, Component, Inject, Injectable, InjectionToken, NgModule } from '@angular/core';
import '@angular/platform-browser';
import { Router, RouterModule } from '@angular/router';
import { animate, state, style, transition, trigger } from '@angular/animations';
import { CommonModule } from '@angular/common';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const baseAnimation = trigger('baseAnimation', [
    state('void', style({ position: 'fixed', opacity: 0 })),
    // route 'enter' transition
    transition(':enter', [
        // css styles at start of transition
        style({ opacity: 0, "z-index": "1001" }),
        // animation and styles at end of transition
        animate('20s', style({ opacity: 1, "z-index": "1001" }))
    ]),
    transition(':leave', [
        // css styles at start of transition
        style({ opacity: 1 }),
        // animation and styles at end of transition
        animate('20s', style({ opacity: 0 }))
    ]),
]);

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ModalOutletComponent {
    constructor() {
    }
}
ModalOutletComponent.decorators = [
    { type: Component, args: [{
                selector: 'modal-outlet',
                template: `
    <router-outlet name="modal"></router-outlet>
  `,
                animations: []
            },] },
];
/** @nocollapse */
ModalOutletComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ModalService {
    /**
     * @param {?} router
     */
    constructor(router$$1) {
        this.router = router$$1;
    }
    /**
     * @param {?} name
     * @return {?}
     */
    open(name) {
        this.router.navigate([{ outlets: { modal: [name] } }], { skipLocationChange: true });
    }
    /**
     * @return {?}
     */
    close() {
        this.router.navigate([{ outlets: { modal: null } }], { skipLocationChange: true });
    }
}
ModalService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ModalService.ctorParameters = () => [
    { type: Router, decorators: [{ type: Inject, args: [Router,] },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ModalDialogComponent {
    /**
     * @param {?} modalService
     */
    constructor(modalService) {
        this.modalService = modalService;
    }
    /**
     * @return {?}
     */
    close() {
        this.modalService.close();
    }
}
ModalDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'modal-dialog',
                template: `
    <div  @baseAnimation>
    <div  class="modal fade in show" tabindex="-1" role="dialog">
        <div class="modal-dialog modal-lg" role="document">
          <div class="modal-content">
            <div class="modal-header">
              <button type="button" (click)="close()" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
              <h4 class="modal-title">
                <ng-content select="[modal-title]"></ng-content>
              </h4>
            </div>
            <div class="modal-body">
                <ng-content select="[modal-body]"></ng-content>
            </div>
            <div class="modal-footer">
                <div #footer>
                    <ng-content select="[modal-footer]"></ng-content>
                </div>
                <div *ngIf="footer.children.length == 0">
                    <button (click)="close()" type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                    <button type="button" class="btn btn-primary">Submit</button>
                </div>
            </div>
          </div>
        </div>
      </div>
      <div class="modal-backdrop fade in"></div>

    </div>
  `,
                animations: [
                    baseAnimation
                ]
            },] },
];
/** @nocollapse */
ModalDialogComponent.ctorParameters = () => [
    { type: ModalService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
//import { ANALYZE_FOR_ENTRY_COMPONENTS } from "@angular/core";
const Modals = new InjectionToken('modals');
/**
 * @param {?} router
 * @param {?} modals
 * @return {?}
 */
function InitModalService(router$$1, modals) {
    var /** @type {?} */ routes = modals.map(t => { return { path: t.name, component: t.component, outlet: 'modal' }; });
    var /** @type {?} */ r = router$$1.config.concat(routes);
    router$$1.resetConfig(r);
    return new ModalService(router$$1);
}
class ModalCommonModule {
}
ModalCommonModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    BrowserAnimationsModule,
                    RouterModule.forChild([])
                ],
                declarations: [
                    ModalDialogComponent,
                    ModalOutletComponent
                ],
                exports: [
                    ModalDialogComponent,
                    ModalOutletComponent
                ],
                providers: []
            },] },
];
/** @nocollapse */
ModalCommonModule.ctorParameters = () => [];
class RouterModalModule {
    /**
     * @param {?} modals
     * @return {?}
     */
    static forRoot(modals) {
        var /** @type {?} */ routes = modals.map(t => { return { path: t.name, component: t.component, outlet: 'modal' }; });
        return {
            ngModule: RouterModalModule,
            providers: [
                { provide: Modals, useValue: modals },
                { provide: ANALYZE_FOR_ENTRY_COMPONENTS, multi: true, useValue: modals },
                { provide: ModalService, useFactory: InitModalService, deps: [Router, Modals] }
            ]
        };
    }
}
RouterModalModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ModalCommonModule
                ],
                exports: [
                    ModalCommonModule
                ]
            },] },
];
/** @nocollapse */
RouterModalModule.ctorParameters = () => [];
class ModalModule {
    /**
     * @param {?} modals
     * @return {?}
     */
    static forRoot(modals) {
        return {
            ngModule: ModalModule,
            providers: [
                { provide: Modals, useValue: modals },
                { provide: ANALYZE_FOR_ENTRY_COMPONENTS, multi: true, useValue: modals },
                { provide: ModalService, useFactory: InitModalService, deps: [Router, Modals] }
            ]
        };
    }
}
ModalModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ModalCommonModule,
                    RouterModule.forRoot([])
                ],
                exports: [
                    ModalCommonModule
                ],
                providers: []
            },] },
];
/** @nocollapse */
ModalModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * @module
 * @description
 * Entry point for all public APIs of the core package.
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { Modals, InitModalService, ModalCommonModule, RouterModalModule, ModalModule, ModalService, ModalDialogComponent as ɵa, ModalOutletComponent as ɵc, baseAnimation as ɵb };
//# sourceMappingURL=index.es6.js.map
